=== modified file 'utilities/local-latency'
--- utilities/local-latency	2011-08-04 15:50:52 +0000
+++ utilities/local-latency	2011-08-04 19:19:42 +0000
@@ -2,12 +2,12 @@
 
 __metaclass__ = type
 
+from optparse import OptionParser
 import sys
 import subprocess
 
 from script_commands import (
     Command,
-    OptionParser,
     UserError,
     )
 

=== modified file 'utilities/script_commands.py'
--- utilities/script_commands.py	2011-08-04 15:50:52 +0000
+++ utilities/script_commands.py	2011-08-04 19:19:42 +0000
@@ -1,31 +1,10 @@
-import optparse
+import inspect
 
 
 class UserError(Exception):
     pass
 
 
-class OptionParser(optparse.OptionParser):
-
-    UNSPECIFIED = object()
-
-    def add_option(self, *args, **kwargs):
-        """Add an option, with the default that it not be included."""
-        kwargs['default'] = kwargs.get('default', self.UNSPECIFIED)
-        optparse.OptionParser.add_option(self, *args, **kwargs)
-
-    def parse_args_dict(self, cmd_args):
-        """Return a dict of specified options.
-
-        Unspecified options with no explicit default are not included in the
-        dict."""
-        options, args = self.parse_args(cmd_args)
-        option_dict = dict(
-            item for item in options.__dict__.items()
-            if item[1] is not self.UNSPECIFIED)
-        return args, option_dict
-
-
 class Command:
     """Base class for subcommands."""
 
@@ -38,9 +17,23 @@
         return {}
 
     @classmethod
+    def set_defaults(cls, parser):
+        args, ignored, ignored, defaults = inspect.getargspec(cls.run)
+        if defaults is None:
+            return
+        defaults_dict = dict(zip(args, defaults))
+        option_defaults = dict(
+            (key, value) for key, value in defaults_dict.items()
+            if parser.defaults.get(key, '') is None)
+        parser.set_defaults(**option_defaults)
+
+    @classmethod
     def run_from_args(cls, cmd_args):
-        args, kwargs = cls.get_parser().parse_args_dict(cmd_args)
-        kwargs.update(cls.parse_args(args))
+        parser = cls.get_parser()
+        cls.set_defaults(parser)
+        options, args = parser.parse_args(cmd_args)
+        kwargs = cls.parse_args(args)
+        kwargs.update(options.__dict__)
         cls.run(**kwargs)
 
     @classmethod

